@@ -4,8 +4,7 @@ From https://github.com/shiftlab/lightning_sphinx_theme.
 """
 from os import path
 
-__version__ = '0.0.1'
-__version_full__ = __version__
+from .extras import *
 
 
 def get_html_theme_path():
